/*
 * JBoss, Home of Professional Open Source
 * Copyright 2010, Red Hat, Inc., and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package nl.meandi.examples;

import java.io.ByteArrayOutputStream;
import java.io.IOException;

import org.apache.http.HttpEntity;
import org.apache.http.HttpResponse;
import org.apache.http.client.HttpClient;
import org.apache.http.client.methods.HttpGet;
import org.apache.http.impl.client.DefaultHttpClient;
import org.jboss.arquillian.api.Deployment;
import org.jboss.arquillian.api.Run;
import org.jboss.arquillian.api.RunModeType;
import org.jboss.arquillian.junit.Arquillian;
import org.jboss.shrinkwrap.api.Archive;
import org.jboss.shrinkwrap.api.ShrinkWrap;
import org.jboss.shrinkwrap.api.spec.WebArchive;
import org.junit.Assert;
import org.junit.Test;
import org.junit.runner.RunWith;

@RunWith(Arquillian.class)
@Run(RunModeType.AS_CLIENT)
public class InjectionTest
{

   @Deployment
   public static Archive<?> createTestArchive()
   {
      WebArchive war = ShrinkWrap.create(WebArchive.class, "test.war");
      war.addClass(TestServlet.class);
      war.addClass(ServletInstaller.class);
      war.addClass(RequestScopedBean.class);
      war.addWebResource("beans.xml", "beans.xml");
      war.addWebResource("web.xml", "web.xml");
      return war;
   }

   @Test
   public void testServletRegisteredInWebXml()
   {
      checkServletResponse("http://localhost:8080/test/servlet1/foo");
   }

   @Test
   public void testServletRegisteredProgramatically()
   {
      checkServletResponse("http://localhost:8080/test/servlet2/foo");
   }

   private void checkServletResponse(String url)
   {
      try
      {
         HttpClient httpClient = new DefaultHttpClient();
         HttpGet request = new HttpGet(url);
         HttpResponse response = httpClient.execute(request);

         HttpEntity entity = response.getEntity();
         if (entity != null)
         {
            ByteArrayOutputStream outputStream = new ByteArrayOutputStream();
            entity.writeTo(outputStream);
            String responseBody = outputStream.toString("UTF-8");
            Assert.assertEquals("OK", responseBody);
         }
         else
         {
            Assert.fail();
         }
      }
      catch (IOException e)
      {
         throw new RuntimeException(e);
      }
   }
}
